==> iReport-1.1.0-src.zip: iReport-1.1.0-src/src/it/businesslogic/ireport/chart/XYZSeries.java <==
/*
 * CategorySeries.java
 *
 * Created on 17 agosto 2005, 10.56
 *
 * To change this template, choose Tools | Options and locate the template under
 * the Source Creation and Management node. Right-click the template and choose
 * Open. You can then make changes to the template in the Source Editor.
 */

package it.businesslogic.ireport.chart;

/**
 *
 * @author Administrator
 */
public class XYZSeries {
    
    private String seriesExpression = "";
    private String xValueExpression = "";
    private String yValueExpression = "";
    private String zValueExpression = "";
    
    /** Creates a new instance of CategorySeries */
    public XYZSeries() {
    }

    public String getSeriesExpression() {
        return seriesExpression;
    }

    public void setSeriesExpression(String seriesExpression) {
        this.seriesExpression = seriesExpression;
    }
    
    public String toString()
    {
        String str = getSeriesExpression();
        if (str == null) str = "";
        if (str.length() > 50) str = str.substring(0,30);
        
        return "XYZ series [" + str + "]";
    }

    public String getXValueExpression() {
        return xValueExpression;
    }

    public void setXValueExpression(String xValueExpression) {
        this.xValueExpression = xValueExpression;
    }

    public String getYValueExpression() {
        return yValueExpression;
    }

    public void setYValueExpression(String yValueExpression) {
        this.yValueExpression = yValueExpression;
    }

    public String getZValueExpression() {
        return zValueExpression;
    }

    public void setZValueExpression(String zValueExpression) {
        this.zValueExpression = zValueExpression;
    }
    
    public XYZSeries cloneMe()
    {
        XYZSeries cs = new XYZSeries();
        cs.setSeriesExpression( this.getSeriesExpression());
        cs.setXValueExpression( this.getXValueExpression());
        cs.setYValueExpression( this.getYValueExpression());
        cs.setZValueExpression( this.getZValueExpression());
        
        return cs;
    }
    
}

==> iReport-1.2.6-src.zip: iReport-1.2.6-src/src/it/businesslogic/ireport/chart/XYZSeries.java <==
/*
 * CategorySeries.java
 *
 * Created on 17 agosto 2005, 10.56
 *
 * To change this template, choose Tools | Options and locate the template under
 * the Source Creation and Management node. Right-click the template and choose
 * Open. You can then make changes to the template in the Source Editor.
 */

package it.businesslogic.ireport.chart;

/**
 *
 * @author Administrator
 */
public class XYZSeries {
    
    private String seriesExpression = "";
    private String xValueExpression = "";
    private String yValueExpression = "";
    private String zValueExpression = "";
    private SectionItemHyperlink sectionItemHyperlink = new SectionItemHyperlink();
    
    /** Creates a new instance of CategorySeries */
    public XYZSeries() {
    }

    public String getSeriesExpression() {
        return seriesExpression;
    }

    public void setSeriesExpression(String seriesExpression) {
        this.seriesExpression = seriesExpression;
    }
    
    public String toString()
    {
        String str = getSeriesExpression();
        if (str == null) str = "";
        if (str.length() > 50) str = str.substring(0,30);
        
        return "XYZ series [" + str + "]";
    }

    public String getXValueExpression() {
        return xValueExpression;
    }

    public void setXValueExpression(String xValueExpression) {
        this.xValueExpression = xValueExpression;
    }

    public String getYValueExpression() {
        return yValueExpression;
    }

    public void setYValueExpression(String yValueExpression) {
        this.yValueExpression = yValueExpression;
    }

    public String getZValueExpression() {
        return zValueExpression;
    }

    public void setZValueExpression(String zValueExpression) {
        this.zValueExpression = zValueExpression;
    }
    
    public XYZSeries cloneMe()
    {
        XYZSeries cs = new XYZSeries();
        cs.setSeriesExpression( this.getSeriesExpression());
        cs.setXValueExpression( this.getXValueExpression());
        cs.setYValueExpression( this.getYValueExpression());
        cs.setZValueExpression( this.getZValueExpression());
        cs.setSectionItemHyperlink( this.getSectionItemHyperlink().cloneMe());
        
        return cs;
    }

    public SectionItemHyperlink getSectionItemHyperlink() {
        return sectionItemHyperlink;
    }

    public void setSectionItemHyperlink(SectionItemHyperlink sectionItemHyperlink) {
        this.sectionItemHyperlink = sectionItemHyperlink;
    }
    
}
